@@ -1,12 +1,13 @@
 // ----------------------------------------------------------------------------
 // Filename:    KTimeclock.cpp
-// $Date: 2000/02/17 23:28:02 $
-// $Revision: 1.11 $
+// $Date: 2000/09/22 15:00:38 $
+// $Revision: 1.12 $
 // ----------------------------------------------------------------------------
 
 #include <kapp.h>
 #include <kfiledialog.h>
 #include <qmessagebox.h>
+#include <qdir.h>
 
 #include <stdlib.h>         // Needed for getenv()
 #include <sys/stat.h>       // Needed for S_IRWXU, mkdir()
@@ -32,18 +33,18 @@ KTimeclock::KTimeclock ( QWidget* parent, const char* name )
     // ------------------------------------------------------------------------
     // Check to ensure that all of the directories we'll require are present
     // ------------------------------------------------------------------------
-    TestDir( "/.kde" );
-    TestDir( "/.kde/share" );
-    TestDir( "/.kde/share/config" );
-    TestDir( "/.kde/share/apps" );
-    QString dir( "/.kde/share/apps/" );
-    dir += kapp->appName();
-    TestDir( dir );
+    TestDir( "share" );
+    TestDir( "share/config" );
+    TestDir( "share/apps" );
+    TestDir( "share/apps/ktimeclock" );
 
     // ------------------------------------------------------------------------
     // Load in any existing data file and trigger a visual refresh.
     // ------------------------------------------------------------------------
-    this->load();
+    if (this->load())
+    {
+        QMessageBox::warning( this, "Error", "Unable to load data file." );
+    }
     treeProjects->triggerUpdate();
 }
 
@@ -443,6 +444,11 @@ int KTimeclock::save()
 // ----------------------------------------------------------------------------
 void KTimeclock::_recursiveSave( QTextStream& str, KTimeclockListItem* item, int depth )
 {
+    // ------------------------------------------------------------------------
+    // If we were given a bogus item to work with, return immediately.
+    // ------------------------------------------------------------------------
+    if (item == NULL) { return; }
+
     // ------------------------------------------------------------------------
     // Output ourselves into the stream
     // ------------------------------------------------------------------------
@@ -472,7 +478,8 @@ void KTimeclock::_recursiveSave( QTextStream& str, KTimeclockListItem* item, int
 // Function:    load ()
 // ----------------------------------------------------------------------------
 // Opens our data file, loads in all of the information, and then calls off to
-// have all the information stuffed into our tree-view.
+// have all the information stuffed into our tree-view.  Returns non-zero on
+// failure to load data file.
 // ----------------------------------------------------------------------------
 int KTimeclock::load()
 {
@@ -499,6 +506,9 @@ int KTimeclock::load()
         failed = 0;
         infile.close();
     }
+    else
+    {
+    }
 
     return (failed);
 }
@@ -620,20 +630,30 @@ void KTimeclock::ShowPopup( QListViewItem* item, const QPoint& loc, int )
 
 // ----------------------------------------------------------------------------
 // Function:    TestDir (const char* name)
-// Parameters:  name    - Path to directory to test for/create underneath $HOME
+// Parameters:  name    - Path to directory to test for/create in local KDE dir
 // ----------------------------------------------------------------------------
-// Tests for the existence of a given directory underneath $HOME and creates it
-// if it doesn't exist.
+// Tests for the existence of a given directory underneath the local KDE
+// directory, creating it if it doesn't exist.
 // ----------------------------------------------------------------------------
 void KTimeclock::TestDir (const char* name)
 {
-    DIR* dp;
-    QString dir = getenv( "HOME" );
-    dir += name;
+    // ------------------------------------------------------------------------
+    // Start off in the local KDE dir; everything we're looking for should be
+    // under here.
+    // ------------------------------------------------------------------------
+    QDir dir( kapp->localkdedir() );
 
-    dp = opendir( dir );
-    if (dp == NULL)
-        mkdir( dir, S_IRWXU );
+    // ------------------------------------------------------------------------
+    // See if this directory exists.
+    // ------------------------------------------------------------------------
+    if (dir.cd( name ))
+    {
+    }
     else
-        closedir( dp );
+    {
+        if (!dir.mkdir( name ))
+        {
+            warning( "Could not create directory '%s'", name );
+        }
+    }
 }
